<?php

namespace App\Controllers;

use App\Models\FlightModel;
use CodeIgniter\API\ResponseTrait;

class FlightManagement extends BaseController
{
    use ResponseTrait;

    protected $flightModel;

    public function __construct()
    {
        $this->flightModel = new FlightModel();
    }

    public function index()
    {
        if (!in_array(session()->get('role'), ['admin', 'agent'])) {
            return redirect()->to('/dashboard')->with('error', 'Access denied.');
        }

        $data['flights'] = $this->flightModel->findAll();
        return view('flight_management/index', $data);
    }

    public function add()
    {
        if (!in_array(session()->get('role'), ['admin', 'agent'])) {
            return $this->respond(['success' => false, 'message' => 'Access denied.'], 403);
        }

        $rules = [
            'flight_number' => 'required|min_length[2]|max_length[20]',
            'departure_city' => 'required|min_length[2]|max_length[100]',
            'arrival_city' => 'required|min_length[2]|max_length[100]',
            'departure_time' => 'required',
            'arrival_time' => 'required',
        ];

        if (!$this->validate($rules)) {
            return $this->respond(['success' => false, 'message' => $this->validator->getErrors()], 400);
        }

        $data = $this->request->getPost();

        // Convert datetime-local input to MySQL datetime format
        $data['departure_time'] = date('Y-m-d H:i:s', strtotime($data['departure_time']));
        $data['arrival_time'] = date('Y-m-d H:i:s', strtotime($data['arrival_time']));

        try {
            if ($this->flightModel->insert($data)) {
                return $this->respond(['success' => true, 'message' => 'Flight added successfully.'], 200);
            } else {
                return $this->respond(['success' => false, 'message' => 'Failed to add flight.'], 400);
            }
        } catch (\Exception $e) {
            log_message('error', 'Error adding flight: ' . $e->getMessage());
            return $this->respond(['success' => false, 'message' => 'An error occurred while adding the flight.'], 500);
        }
    }

    public function delete($id)
    {
        if (!in_array(session()->get('role'), ['admin', 'agent'])) {
            return $this->respond(['success' => false, 'message' => 'Access denied.'], 403);
        }

        try {
            if ($this->flightModel->delete($id)) {
                return $this->respond(['success' => true, 'message' => 'Flight deleted successfully.'], 200);
            } else {
                return $this->respond(['success' => false, 'message' => 'Failed to delete flight.'], 400);
            }
        } catch (\Exception $e) {
            log_message('error', 'Error deleting flight: ' . $e->getMessage());
            return $this->respond(['success' => false, 'message' => 'An error occurred while deleting the flight.'], 500);
        }
    }
}