<?php

namespace App\Models;

use CodeIgniter\Model;

class RequestModel extends Model
{
    protected $table = 'requests';
    protected $primaryKey = 'id';
    protected $allowedFields = ['unique_id', 'user_id', 'arrival_flight_id', 'departure_flight_id', 'status', 'created_at', 'updated_at'];

    public function getAllRequests()
    {
        return $this->select('requests.*, IFNULL(users.username, "Unknown") as username')
                    ->join('users', 'users.id = requests.user_id', 'left')
                    ->orderBy('requests.created_at', 'DESC')
                    ->findAll();
    }

    public function getUserRequests($userId)
    {
        return $this->where('user_id', $userId)
                    ->orderBy('created_at', 'DESC')
                    ->findAll();
    }

    public function getRequestDetails($id)
	{
    $request = $this->select('requests.*, users.username, f1.flight_number as arrival_flight_number, f2.flight_number as departure_flight_number')
                   ->join('users', 'users.id = requests.user_id')
                   ->join('flights as f1', 'f1.id = requests.arrival_flight_id', 'left')
                   ->join('flights as f2', 'f2.id = requests.departure_flight_id', 'left')
                   ->where('requests.id', $id)
                   ->first();

    if ($request) {
        $request['passengers'] = $this->getRequestPassengers($id);
    }

    return $request;
  }
  
  
  
  	public function getRequestHotels($requestId)
	{
    log_message('debug', "Fetching hotels for request ID: $requestId");
    
    $sql = "SELECT rh.*, 
                   IFNULL(h.name, 'Unknown Hotel') as hotel_name, 
                   IFNULL(rt.name, 'Unknown Room Type') as room_type
            FROM request_hotels rh
            LEFT JOIN hotels h ON h.id = rh.hotel_id
            LEFT JOIN rooms r ON r.id = rh.room_id
            LEFT JOIN room_types rt ON rt.id = r.room_type_id
            WHERE rh.request_id = ?";

    //log_message('debug', "SQL Query: $sql");

    $query = $this->db->query($sql, [$requestId]);
    $result = $query->getResultArray();

    //log_message('debug', 'Query Result: ' . print_r($result, true));
    //log_message('debug', 'Number of hotels found: ' . count($result));

    return $result;
	}

    protected function getRequestPassengers($requestId)
    {
        $db = \Config\Database::connect();
        return $db->table('passengers')
                  ->where('request_id', $requestId)
                  ->get()
                  ->getResultArray();
    }

    public function searchRequests($searchTerm)
    {
        return $this->select('requests.*, IFNULL(users.username, "Unknown") as username')
                    ->join('users', 'users.id = requests.user_id', 'left')
                    ->like('requests.unique_id', $searchTerm)
                    ->orLike('users.username', $searchTerm)
                    ->orderBy('requests.created_at', 'DESC')
                    ->findAll();
    }
  
  	
}